R/Module_Barretts.R
BarrettsParisEMR.RdThis creates a column of Paris grade for all samples where this is mentioned.
BarrettsParisEMR(Column, Column2)
| Column | Endoscopy report field of interest as a string vector |
|---|---|
| Column2 | Another endoscopy report field of interest as a string vector |
a string vector
Other Disease Specific Analysis - Barretts Data:
BarrettsAll(),
BarrettsBxQual(),
Barretts_FUType(),
Barretts_PathStage(),
Barretts_PragueScore()
# Myendo$EMR<-BarrettsParisEMR(Myendo$ProcedurePerformed,Myendo$Findings)