This does a general clean up of whitespace, semi-colons,full stops at the start of lines and converts end sentence full stops to new lines.
ColumnCleanUp(vector)
| vector | column of interest |
|---|
This returns a character vector
Other NLP - Text Cleaning and Extraction:
DictionaryInPlaceReplace(),
Extractor(),
NegativeRemoveWrapper(),
NegativeRemove(),
textPrep()
ii<-ColumnCleanUp(Myendo$Findings)