R/Basic_CleanUp.R
EntityPairs_OneSentence.RdSee if words from two lists co-exist within a sentence. Eg site and tissue type. This function only looks in one sentence for the two terms. If you suspect the terms may occur in adjacent sentences then use the EntityPairs_TwoSentence function.
EntityPairs_OneSentence(inputText, list1, list2)
| inputText | The relevant pathology text column |
|---|---|
| list1 | First list to refer to |
| list2 | The second list to look for |
Other Basic Column mutators:
EntityPairs_TwoSentence(),
ExtrapolatefromDictionary(),
ListLookup(),
MyImgLibrary()
# tbb<-EntityPairs_OneSentence(Mypath$Histology,HistolType(),LocationList())