This is used to look for relationships between site and event especially for endoscopy events where sentences such as 'The stomach polyp was large. It was removed with a snare' ie the therapy and the site are in two different locations.
EntityPairs_TwoSentence(inputString, list1, list2)
| inputString | The relevant pathology text column |
|---|---|
| list1 | The intial list to assess |
| list2 | The other list to look for |
Other Basic Column mutators:
EntityPairs_OneSentence(),
ExtrapolatefromDictionary(),
ListLookup(),
MyImgLibrary()
# tbb<-EntityPairs_TwoSentence(Myendo$Findings,EventList(),HistolType())