This is used to pick and clean endoscopic images from html exports so they can be prepared before being linked to pathology and endoscopy reports
MyImgLibrary(file, delim, location)
| file | The html report to extract (the html will have all the images references in it) |
|---|---|
| delim | The phrase that separates individual endoscopies |
| location | The folder containing the actual images |
Other Basic Column mutators:
EntityPairs_OneSentence(),
EntityPairs_TwoSentence(),
ExtrapolatefromDictionary(),
ListLookup()
# MyImgLibrary("S:/Gastroenterology/Seb/R/Data/Barretts/Images Captured with Proc Data Audit_Findings1.html", # "procedureperformed","S:/Gastroenterology/Seb/R/Data/Barretts/")