This standardises the colours for any ggplot plot produced. If you do use it, like all ggplots it can be extended using the "+" to add whatever else is necessary
scale_colour_Publication()
Other Data Presentation helpers:
EndoBasicGraph(),
scale_fill_Publication(),
theme_Publication()
# None needed