This standardises the theme for any ggplot plot produced. If you do use it, like all ggplots it can be extended using the "+" to add whatever else is necessary
theme_Publication(base_size = 14, base_family = "Helvetica")
| base_size | the base size |
|---|---|
| base_family | the base family |
Other Data Presentation helpers:
EndoBasicGraph(),
scale_colour_Publication(),
scale_fill_Publication()
# None needed